from setuptools import setup, find_packages


setup(
    name='zfp',
    author='Ouroboros Chrysopoeia',
    author_email='impredicative@users.nomail.github.com',
    version='0.0.0',
    packages=find_packages(),
)
